@@ -20,23 +20,26 @@
 #'
 #' result |>
 #'   plotObservationPeriod(
-#'     variableName = "duration in days",
+#'     variableName = "Duration in days",
 #'     plotType = "boxplot"
 #'   )
 #'
 #' PatientProfiles::mockDisconnect(cdm)
 #' }
 plotObservationPeriod <- function(result,
-                                  variableName = "number subjects",
+                                  variableName = "Number subjects",
                                   plotType = "barplot",
                                   facet = NULL,
                                   colour = NULL) {
+
+  rlang::check_installed("ggplot2")
+  rlang::check_installed("visOmopResults")
   # initial checks
   omopgenerics::validateResultArgument(result)
 
   # subset to result_type of interest
   result <- result |>
-    visOmopResults::filterSettings(
+    omopgenerics::filterSettings(
       .data$result_type == "summarise_observation_period")
 
   # check if it is empty
@@ -57,19 +60,18 @@ plotObservationPeriod <- function(result,
 
   validateFacet(facet, result)
 
-  optFacetColour <- visOmopResults::tidyColumns(result)
-  optFacetColour <- optFacetColour[optFacetColour %in% visOmopResults::tidyColumns(result)]
-  omopgenerics::assertChoice(facet, optFacetColour, null = TRUE, call = call)
+  optFacetColour <- c("cdm_name", "observation_period_ordinal",
+                      omopgenerics::strataColumns(result))
+  omopgenerics::assertChoice(facet, optFacetColour, null = TRUE)
 
   # this is due to bug in visOmopResults to remove in next release
   # https://github.com/darwin-eu/visOmopResults/issues/246
   if (length(facet) == 0) facet <- NULL
   if (length(colour) == 0) colour <- NULL
 
-  if(length(visOmopResults::groupColumns(result)) == 0){
+  if(length(omopgenerics::groupColumns(result)) == 0){
     result <- result |>
-      dplyr::mutate(group_name  = "observation_period_ordinal",
-             group_level = "Overall")
+      dplyr::mutate(group_name  = "observation_period_ordinal")
   }
 
   if (plotType == "barplot") {
@@ -86,7 +88,7 @@ plotObservationPeriod <- function(result,
       x = "observation_period_ordinal",
       facet = facet,
       colour = colour)
-  } else {
+  } else if (plotType == "densityplot") {
     p <- visOmopResults::scatterPlot(
       result = result,
       x = "density_x",
@@ -96,7 +98,8 @@ plotObservationPeriod <- function(result,
       ribbon = FALSE,
       facet = facet,
       colour = colour,
-      group = optFacetColour) +
+      group = optFacetColour
+    ) +
       ggplot2::xlab(stringr::str_to_sentence(unique(result$variable_name))) +
       ggplot2::ylab("Density")
   }
@@ -107,13 +110,13 @@ plotObservationPeriod <- function(result,
 availablePlotObservationPeriod <- function() {
   dplyr::tribble(
     ~variable_name, ~plot_type, ~facet,
-    "number subjects", "barplot", "cdm_name+observation_period_ordinal",
-    "records per person", "densityplot", "cdm_name",
-    "records per person", "boxplot", "cdm_name",
-    "duration in days", "densityplot", "cdm_name+observation_period_ordinal",
-    "duration in days", "boxplot", "cdm_name+observation_period_ordinal",
-    "days to next observation period", "densityplot", "cdm_name+observation_period_ordinal",
-    "days to next observation period", "boxplot", "cdm_name+observation_period_ordinal",
+    "Number subjects", "barplot", "cdm_name+observation_period_ordinal",
+    "Records per person", "densityplot", "cdm_name",
+    "Records per person", "boxplot", "cdm_name",
+    "Duration in days", "densityplot", "cdm_name+observation_period_ordinal",
+    "Duration in days", "boxplot", "cdm_name+observation_period_ordinal",
+    "Days to next observation period", "densityplot", "cdm_name+observation_period_ordinal",
+    "Days to next observation period", "boxplot", "cdm_name+observation_period_ordinal",
   )
 }
 needEstimates <- function(plotType) {
