@@ -20,7 +20,7 @@ tableOmopSnapshot <- function(result,
   # initial checks
   rlang::check_installed("visOmopResults")
   omopgenerics::validateResultArgument(result)
-  omopgenerics::assertChoice(type, choicesTables())
+  omopgenerics::assertChoice(type, visOmopResults::tableType())
 
   # subset to result_type of interest
   result <- result |>
@@ -32,14 +32,18 @@ tableOmopSnapshot <- function(result,
     warnEmpty("summarise_omop_snapshot")
     return(emptyTable(type))
   }
-
+  if (type == "datatable" && dplyr::n_distinct(result$cdm_name) == 1) {
+    header <- NULL
+  } else {
+    header <- c("cdm_name")
+  }
   result <- result |>
     formatColumn(c("variable_name", "estimate_name")) |>
     visOmopResults::visOmopTable(
       type = type,
       hide = c("variable_level"),
       estimateName = c("N" = "<Count>"),
-      header = c("cdm_name"),
+      header = header,
       rename = c(
         "Database name" = "cdm_name",
         "Estimate" = "estimate_name",
@@ -64,9 +68,7 @@ emptyTable <- function(type) {
     "flextable" = flextable::flextable(x)
   )
 }
-choicesTables <- function() {
-  c("tibble", "flextable", "gt")
-}
+
 formatColumn <- function(result, col) {
   for (x in col) {
     result <- result |>
